@@ -1,7 +1,7 @@
 mod string_repr;
 mod uri_fragment;
 
-use JsonPointer;
+use crate::JsonPointer;
 
 /// A parser for JSON pointers. If the string starts with a `#`, it is parsed
 /// as a URI fragment. Otherwise, it is parsed in the string representation.
